@@ -1,6 +1,12 @@
-<?php get_header(); ?>
+<?php
+/**
+ * @package WordPress
+ * @subpackage Default_Theme
+ */
 
-	<div id="content" class="narrowcolumn">
+get_header(); ?>
+
+	<div id="content" class="narrowcolumn" role="main">
 
 	<?php if (have_posts()) : ?>
 
@@ -14,7 +20,7 @@
 
 		<?php while (have_posts()) : the_post(); ?>
 
-			<div class="post">
+			<div <?php post_class() ?>>
 				<h3 id="post-<?php the_ID(); ?>"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent Link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a></h3>
 				<small><?php the_time('l, F jS, Y') ?></small>
 
@@ -31,7 +37,7 @@
 	<?php else : ?>
 
 		<h2 class="center">No posts found. Try a different search?</h2>
-		<?php include (TEMPLATEPATH . '/searchform.php'); ?>
+		<?php get_search_form(); ?>
 
 	<?php endif; ?>
 
@@ -39,4 +45,4 @@
 
 <?php get_sidebar(); ?>
 
-<?php get_footer(); ?>
\ No newline at end of file
+<?php get_footer(); ?>
